"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChannelType = exports.OptionType = exports.SlashCommandOptionBuilder = exports.SlashCommandBuilder = void 0;
const toPermissionBitfield_1 = require("../utils/toPermissionBitfield");
const v10_1 = require("discord-api-types/v10");
Object.defineProperty(exports, "ChannelType", { enumerable: true, get: function () { return v10_1.ChannelType; } });
const discord_js_1 = require("discord.js");
class SlashCommandBuilder extends discord_js_1.SlashCommandBuilder {
    type = 1;
    application_id;
    guild_id;
    name;
    description;
    options;
    dm_permission;
    constructor(data) {
        super();
        this.name = data.name;
        if (data.name_localizations) {
            this.name_localizations = data.name_localizations;
        }
        this.description = data.description;
        if (data.description_localizations) {
            this.description_localizations = data.description_localizations;
        }
        this.options = data.options?.map((option) => new SlashCommandOptionBuilder(option));
        if (data.default_member_permissions) {
            this.default_member_permissions = (0, toPermissionBitfield_1.toPermissionBitfield)(data.default_member_permissions).toString();
        }
        this.dm_permission = data.dm_permission;
    }
}
exports.SlashCommandBuilder = SlashCommandBuilder;
class SlashCommandOptionBuilder {
    type;
    name;
    name_localizations;
    description;
    description_localizations;
    required;
    choices;
    options;
    channel_types;
    min_value;
    max_value;
    min_length;
    max_length;
    autocomplete;
    toJSON() {
        return {
            type: this.type,
            name: this.name,
            description: this.description,
            required: this.required,
            choices: this.choices,
            options: this.options?.map((option) => option.toJSON()),
            channel_types: this.channel_types,
            min_value: this.min_value,
            max_value: this.max_value,
            min_length: this.min_length,
            max_length: this.max_length,
            autocomplete: this.autocomplete
        };
    }
    constructor(data) {
        this.type = data.type;
        this.name = data.name;
        this.description = data.description;
        this.required = data.required;
        this.choices = data.choices;
        this.options = data.options?.map(option => new SlashCommandOptionBuilder(option));
        this.channel_types = data.channel_types;
        this.min_value = data.min_value;
        this.max_value = data.max_value;
        this.min_length = data.min_length;
        this.max_length = data.max_length;
        this.autocomplete = data.autocomplete;
    }
}
exports.SlashCommandOptionBuilder = SlashCommandOptionBuilder;
var OptionType;
(function (OptionType) {
    OptionType[OptionType["Subcommand"] = 1] = "Subcommand";
    OptionType[OptionType["SubcommandGroup"] = 2] = "SubcommandGroup";
    OptionType[OptionType["String"] = 3] = "String";
    OptionType[OptionType["Integer"] = 4] = "Integer";
    OptionType[OptionType["Boolean"] = 5] = "Boolean";
    OptionType[OptionType["User"] = 6] = "User";
    OptionType[OptionType["Channel"] = 7] = "Channel";
    OptionType[OptionType["Role"] = 8] = "Role";
    OptionType[OptionType["Mentionable"] = 9] = "Mentionable";
    OptionType[OptionType["Number"] = 10] = "Number";
    OptionType[OptionType["Attachment"] = 11] = "Attachment";
})(OptionType = exports.OptionType || (exports.OptionType = {}));
